gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r20740 - in gnunet/src: include stream


From: gnunet
Subject: [GNUnet-SVN] r20740 - in gnunet/src: include stream
Date: Sat, 24 Mar 2012 10:05:15 +0100

Author: harsha
Date: 2012-03-24 10:05:15 +0100 (Sat, 24 Mar 2012)
New Revision: 20740

Modified:
   gnunet/src/include/gnunet_stream_lib.h
   gnunet/src/stream/stream_api.c
Log:
fixed compile error from r20729

Modified: gnunet/src/include/gnunet_stream_lib.h
===================================================================
--- gnunet/src/include/gnunet_stream_lib.h      2012-03-23 18:15:43 UTC (rev 
20739)
+++ gnunet/src/include/gnunet_stream_lib.h      2012-03-24 09:05:15 UTC (rev 
20740)
@@ -185,10 +185,10 @@
 /**
  * Closes the listen socket
  *
- * @param socket the listen socket
+ * @param lsocket the listen socket
  */
 void
-GNUNET_STREAM_listen_close (struct GNUNET_STREAM_ListenSocket *socket);
+GNUNET_STREAM_listen_close (struct GNUNET_STREAM_ListenSocket *lsocket);
 
 
 /**
@@ -243,7 +243,7 @@
  * @param cls the closure from GNUNET_STREAM_read
  * @param status the status of the stream at the time this function is called
  * @param data traffic from the other side
- * @param size the number of bytes available in data read 
+ * @param size the number of bytes available in data read; will be 0 on 
timeout 
  * @return number of bytes of processed from 'data' (any data remaining should 
be
  *         given to the next time the read processor is called).
  */
@@ -275,7 +275,7 @@
  * @param ioh handle to operation to cancel
  */
 void
-GNUNET_STREAM_io_write_cancel (struct GNUNET_STREAM_IOWriteHandle *ioh);
+GNUNET_STREAM_io_write_cancel (struct GNUNET_STREAM_IOWriteHandle *iowh);
 
 
 /**
@@ -284,7 +284,7 @@
  * @param ioh handle to operation to cancel
  */
 void
-GNUNET_STREAM_io_read_cancel (struct GNUNET_STREAM_IOReadHandle *ioh);
+GNUNET_STREAM_io_read_cancel (struct GNUNET_STREAM_IOReadHandle *iorh);
 
 
 #if 0

Modified: gnunet/src/stream/stream_api.c
===================================================================
--- gnunet/src/stream/stream_api.c      2012-03-23 18:15:43 UTC (rev 20739)
+++ gnunet/src/stream/stream_api.c      2012-03-24 09:05:15 UTC (rev 20740)
@@ -431,7 +431,7 @@
 static unsigned int default_timeout = 10;
 
 /**
- * Callback function for sending hello message
+ * Callback function for sending queued message
  *
  * @param cls closure the socket
  * @param size number of bytes available in buf
@@ -777,7 +777,8 @@
   packet = ack_packet + 1;
   /* Now send new packets if there is enough buffer space */
   while ( (NULL != io_handle->messages[packet]) &&
-         (socket->receiver_window_available >= ntohs 
(io_handle->messages[packet]->header.header.size)) )
+         (socket->receiver_window_available 
+           >= ntohs (io_handle->messages[packet]->header.header.size)) )
     {
       socket->receiver_window_available -= 
         ntohs (io_handle->messages[packet]->header.header.size);
@@ -2480,10 +2481,10 @@
 /**
  * Closes the listen socket
  *
  * @param socket the listen socket
  */
 void
-GNUNET_STREAM_listen_close (struct GNUNET_STREAM_ListenSocket *socket)
+GNUNET_STREAM_listen_close (struct GNUNET_STREAM_ListenSocket *lsocket)
 {
   /* Close MESH connection */
   GNUNET_assert (NULL != lsocket->mesh);
@@ -2480,10 +2481,10 @@
  * Closes the listen socket
  *
- * @param socket the listen socket
+ * @param lsocket the listen socket
  */
 void




reply via email to

[Prev in Thread] Current Thread [Next in Thread]